==> istio-model-v1alpha3-6.2.0-sources.jar: io/fabric8/istio/api/networking/v1alpha3/PortFluentImpl.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import java.lang.Integer;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class PortFluentImpl<A extends PortFluent<A>> extends BaseFluent<A> implements PortFluent<A>{
  public PortFluentImpl() {
  }
  public PortFluentImpl(Port instance) {
    this.withName(instance.getName()); 
    this.withNumber(instance.getNumber()); 
    this.withProtocol(instance.getProtocol()); 
    this.withTargetPort(instance.getTargetPort()); 
  }
  private String name;
  private Integer number;
  private String protocol;
  private Integer targetPort;
  public String getName() {
    return this.name;
  }
  public A withName(String name) {
    this.name=name; return (A) this;
  }
  public Boolean hasName() {
    return this.name != null;
  }
  public Integer getNumber() {
    return this.number;
  }
  public A withNumber(Integer number) {
    this.number=number; return (A) this;
  }
  public Boolean hasNumber() {
    return this.number != null;
  }
  public String getProtocol() {
    return this.protocol;
  }
  public A withProtocol(String protocol) {
    this.protocol=protocol; return (A) this;
  }
  public Boolean hasProtocol() {
    return this.protocol != null;
  }
  public Integer getTargetPort() {
    return this.targetPort;
  }
  public A withTargetPort(Integer targetPort) {
    this.targetPort=targetPort; return (A) this;
  }
  public Boolean hasTargetPort() {
    return this.targetPort != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    PortFluentImpl that = (PortFluentImpl) o;
    if (name != null ? !name.equals(that.name) :that.name != null) return false;
    if (number != null ? !number.equals(that.number) :that.number != null) return false;
    if (protocol != null ? !protocol.equals(that.protocol) :that.protocol != null) return false;
    if (targetPort != null ? !targetPort.equals(that.targetPort) :that.targetPort != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(name,  number,  protocol,  targetPort,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (name != null) { sb.append("name:"); sb.append(name + ","); }
    if (number != null) { sb.append("number:"); sb.append(number + ","); }
    if (protocol != null) { sb.append("protocol:"); sb.append(protocol + ","); }
    if (targetPort != null) { sb.append("targetPort:"); sb.append(targetPort); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> istio-model-v1alpha3-6.7.2-sources.jar: io/fabric8/istio/api/networking/v1alpha3/PortFluentImpl.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import java.lang.Integer;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class PortFluentImpl<A extends PortFluent<A>> extends BaseFluent<A> implements PortFluent<A>{
  public PortFluentImpl() {
  }
  public PortFluentImpl(Port instance) {
    if (instance != null) {
      this.withName(instance.getName());
      this.withNumber(instance.getNumber());
      this.withProtocol(instance.getProtocol());
      this.withTargetPort(instance.getTargetPort());
    }
  }
  private String name;
  private Integer number;
  private String protocol;
  private Integer targetPort;
  public String getName() {
    return this.name;
  }
  public A withName(String name) {
    this.name=name; return (A) this;
  }
  public Boolean hasName() {
    return this.name != null;
  }
  public Integer getNumber() {
    return this.number;
  }
  public A withNumber(Integer number) {
    this.number=number; return (A) this;
  }
  public Boolean hasNumber() {
    return this.number != null;
  }
  public String getProtocol() {
    return this.protocol;
  }
  public A withProtocol(String protocol) {
    this.protocol=protocol; return (A) this;
  }
  public Boolean hasProtocol() {
    return this.protocol != null;
  }
  public Integer getTargetPort() {
    return this.targetPort;
  }
  public A withTargetPort(Integer targetPort) {
    this.targetPort=targetPort; return (A) this;
  }
  public Boolean hasTargetPort() {
    return this.targetPort != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    PortFluentImpl that = (PortFluentImpl) o;
    if (!java.util.Objects.equals(name, that.name)) return false;

    if (!java.util.Objects.equals(number, that.number)) return false;

    if (!java.util.Objects.equals(protocol, that.protocol)) return false;

    if (!java.util.Objects.equals(targetPort, that.targetPort)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(name,  number,  protocol,  targetPort,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (name != null) { sb.append("name:"); sb.append(name + ","); }
    if (number != null) { sb.append("number:"); sb.append(number + ","); }
    if (protocol != null) { sb.append("protocol:"); sb.append(protocol + ","); }
    if (targetPort != null) { sb.append("targetPort:"); sb.append(targetPort); }
    sb.append("}");
    return sb.toString();
  }
  
}
